# Behaviors

::: casty.Behavior

::: casty.Behaviors

::: casty.ReceiveBehavior

::: casty.SetupBehavior

::: casty.SameBehavior

::: casty.StoppedBehavior

::: casty.UnhandledBehavior

::: casty.RestartBehavior

::: casty.LifecycleBehavior

::: casty.SupervisedBehavior

::: casty.EventSourcedBehavior

::: casty.PersistedBehavior

::: casty.BroadcastedBehavior

::: casty.ShardedBehavior

::: casty.SpyEvent

::: casty.SnapshotPolicy

::: casty.SnapshotEvery
